/*
 * This file is part of the KDE Milou Project
 * SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
 *
 * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 *
 */

.import org.kde.kirigami 2.20 as Kirigami

// The Maximum and Minimum width of the Plasmoid
var PlasmoidWidth = Kirigami.Units.gridUnit * 35;

// The size in which the Plasmoid switches between compact and full
var SwitchWidth = Kirigami.Units.gridUnit * 20;
